OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s publicou o calendário »%s«",
    "Hello," : "Olá,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informar que %s publicou o calendário »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "Parabéns!",
    "Calendar" : "Calendário",
    "Today" : "Hoje",
    "Day" : "Dia",
    "Week" : "Semana",
    "Month" : "Mês",
    "Download" : "Transferir",
    "Delete" : "Eliminar",
    "Share link" : "Partilhar hiperligação",
    "Delete share link" : "Apagar hiperligação de partilha",
    "Share with users or groups" : "Partilhe com os utilizadores ou grupos",
    "can edit" : "pode editar",
    "New calendar" : "Novo calendário",
    "Filename" : "Nome do ficheiro",
    "Cancel" : "Cancelar",
    "Automatic" : "Automático",
    "Show week numbers" : "Mostrar o número das semanas",
    "Settings & import" : "Definições & importar",
    "Notification" : "Notificação",
    "Email" : "E-mail",
    "Busy" : "Ocupado",
    "Unknown" : "Desconhecido",
    "never" : "nunca",
    "after" : "depois",
    "Repeat" : "Repetir",
    "Monday" : "Segunda",
    "Summary" : "Resumo",
    "More" : "Mais",
    "Save" : "Guardar",
    "Update" : "Atualizar",
    "Personal" : "Pessoal",
    "Details" : "Detalhes",
    "Attendees" : "Participantes",
    "Reminders" : "Lembretes",
    "Activity" : "Actividade",
    "Close" : "Fechar",
    "Anniversary" : "Aniversário",
    "Week {number} of {year}" : "Semana {number} do {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "When shared show full event" : "Quando partilhado, mostrar evento completo",
    "When shared show only busy" : "Quando partilhado, mostrar apenas ocupados",
    "When shared hide this event" : "Quando partilhado, ocultar este evento",
    "Location" : "Localização:",
    "Description" : "Descrição",
    "Status" : "Estado",
    "Confirmed" : "Confirmado",
    "Tentative" : "Tentativa",
    "Cancelled" : "Cancelado",
    "Categories" : "Categorias",
    "Presentation" : "Apresentação",
    "Review" : "Rever",
    "Office" : "Escritório",
    "Mail" : "Correio",
    "Play" : "Reproduzir",
    "Global" : "Global"
},
"nplurals=2; plural=(n != 1);");
